DirectionsResponse class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

DirectionsResponse({required String status, String? errorMessage, required List<GeocodedWaypoint> geocodedWaypoints, required List<Route> routes})
DirectionsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

errorMessage → String?
JSON error_message
finalinherited
geocodedWaypoints → List<GeocodedWaypoint>
JSON geocoded_waypos
final
hashCode → int
The hash code for this object.
no setterinherited
hasNoResults → bool
no setterinherited
isDenied → bool
no setterinherited
isInvalid → bool
no setterinherited
isNotFound → bool
no setterinherited
isOkay → bool
no setterinherited
isOverQueryLimit → bool
no setterinherited
routes → List<Route>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String
finalinherited
unknownError → bool
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited