Route class

Annotations
  • @JsonSerializable.new()

Constructors

Route({required String summary, required List<Leg> legs, required String copyrights, required Polyline overviewPolyline, required List warnings, required List<num> waypointOrder, required Bounds bounds, Fare? fare})
Route.fromJson(Map<String, dynamic> json)
factory

Properties

bounds → Bounds
final
copyrights → String
final
fare → Fare?
final
hashCode → int
The hash code for this object.
no setterinherited
legs → List<Leg>
final
overviewPolyline → Polyline
JSON overview_polyline
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
summary → String
final
warnings → List
final
waypointOrder → List<num>
JSON waypoint_order
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited