DistanceResponse class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

DistanceResponse({required String status, String? errorMessage, required List<String> originAddresses, required List<String> destinationAddresses, required List<Row> rows})
DistanceResponse.fromJson(Map<String, dynamic> json)
factory

Properties

destinationAddress → List<String>
no setter
destinationAddresses → List<String>
final
errorMessage → String?
JSON error_message
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
hasNoResults → bool
no setterinherited
isDenied → bool
no setterinherited
isInvalid → bool
no setterinherited
isNotFound → bool
no setterinherited
isOkay → bool
no setterinherited
isOverQueryLimit → bool
no setterinherited
originAddress → List<String>
no setter
originAddresses → List<String>
final
results → List<Row>
no setter
rows → List<Row>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String
finalinherited
unknownError → bool
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited