GeocodingResult class

Annotations
  • @JsonSerializable.new()

Constructors

GeocodingResult({required Geometry geometry, required String placeId, List<String> types = const <String>[], List<AddressComponent> addressComponents = const <AddressComponent>[], List<String> postcodeLocalities = const <String>[], bool partialMatch = false, String? formattedAddress})
GeocodingResult.fromJson(Map<String, dynamic> json)
factory

Properties

addressComponents → List<AddressComponent>
JSON address_components
final
formattedAddress → String?
JSON formatted_address
final
geometry → Geometry
final
hashCode → int
The hash code for this object.
no setterinherited
partialMatch → bool
JSON partial_match
final
placeId → String
JSON place_id
final
postcodeLocalities → List<String>
JSON postcode_localities
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
types → List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited